import math

class Rocket():
    # Rocket simulates a rocket ship for a game,
    #  or a physics simulation.

    def __init__(self, x=0, y=0):
        # Each rocket has an (x,y) position.
        self.x = x
        self.y = y

    def move_rocket(self, x_increment=0, y_increment=1):
        # Move the rocket according to the paremeters given.
        #  Default behavior is to move the rocket up one unit.
        self.x += x_increment
        self.y += y_increment

    def get_distance(self, other_rocket):
        # Calculates the distance from this rocket to another rocket,
        #  and returns that value.
        distance = math.sqrt((self.x - other_rocket.x) ** 2 + (self.y - other_rocket.y) ** 2)
        return distance

    def __str__(self):
        return f"A Rocket positioned at ({self.x},{self.y})"

    def __repr__(self):
        return f"Rocket({self.x},{self.y})"

    def __eq__(self, other):
        return self.x == other.x and self.y == other.y


class Shuttle(Rocket):
    def __init__(self, x=0, y=0, flights_completed=0):
        super().__init__(x, y)
        self.flights_completed = flights_completed


class CircleRocket(Rocket):
    def __init__(self, r, x=0, y=0):
        super().__init__(x, y)
        self.r = r

    def get_area(self):
        return math.pi * self.r ** 2

    def get_circumference(self):
        return 2 * math.pi * self.r

    def __str__(self):
        return f"CircleRocket with radius {self.r} at position ({self.x}, {self.y})"


from setuptools import setup

setup(
   name='Rocket_FB_1',
   version='1.0.0',
   author='Fadi',
   author_email='benzaimafadi@gmail.com',
   packages=['Rocket'],
   url='http://pypi.python.org/pypi/Rocket_FB_1/',
   license='LICENSE.txt',
   description='An awesome package that does something',
   long_description=open('README.md').read(),
   long_description_content_type="text/markdown",
   install_requires=['']
)